--[[
      Options menu for displays
]]

local addon_name, ns = ...

local Menu = {}

local Locked = {
    text = "Locked"
}
local Rotation = {
    text = "Rotation",
    hasArrow = true,
    menuList = {
        {
            text = "Announce"
        }
    }
}

local Share = {
    text = "Share",
    notCheckable = true
}

local menuinfo = {
    {
        text = "Options",
        isTitle = 1,
        notCheckable = true
    },
    Locked,
    Rotation,
    Share
}


local ddmenu = CreateFrame("Frame", "OakInterruptsDisplay_DrowDownMenu", UIParent, "UIDropDownMenuTemplate")
--[[
ddmenu.point = "LEFT"
ddmenu.relativePoint = "RIGHT"
]]

local function ToggleLock(disp)
    if disp.locked == true then
        ns.display.Unlock(disp)
    else
        ns.display.Lock(disp)
    end
end

local function ToggleRotation(disp)
    if disp.rotation then
        ns.display.SetRotation(disp, false)
    else
        ns.display.SetRotation(disp, true)
    end
end

local function ToggleAnnounce(disp)
    if not disp.rotation or not disp.rotation.announce then
        ns.display.SetRotation(disp, "ANNOUNCE")
    else
        ns.display.SetRotation(disp, true)
    end
end

local function Show(disp)
    Locked.checked = function() return disp.locked == true end
    Locked.func = function() ToggleLock(disp) end
    Rotation.checked = function() return disp.rotation ~= nil end
    Rotation.menuList[1].checked = function()
        return disp.rotation and disp.rotation.announce
    end
    Rotation.func = function() ToggleRotation(disp) end
    Rotation.menuList[1].func = function() ToggleAnnounce(disp) end
    Share.disabled = not disp.rotation and 1 or nil
    Share.func = function() ns.display.ShareRotation(disp) end

    EasyMenu(menuinfo, ddmenu, "cursor", 0, 0, nil, 1)
end

function Menu.Register(disp)
    -- create button
    local btn_opts = CreateFrame("Button", nil, disp.heading)

    btn_opts:SetHighlightTexture("Interface\\Buttons\\UI-OptionsButton")
    btn_opts:SetNormalTexture("Interface\\Buttons\\UI-OptionsButton")

    -- layout button
    local btnpad = 2
    local btnsize = disp.heading:GetHeight()
    btn_opts:SetSize(btnsize, btnsize)
    btn_opts:SetPoint("TOPRIGHT", disp.heading, "TOPRIGHT", -btnpad, 0)

    disp.btn_opts = btn_opts

    btn_opts:SetScript("OnClick", function(self, button, down)
        Show(disp)
    end)
end

--------------------------------------------------------------------------------
ns.Menu = Menu
